#!/bin/bash
#VirtualCam Config script for IGEL
#Version 1.1
#Author: Alexander Täffner - https://taeffner.net

WCBLUR=80 #set this to the desired blur value, if the user selects to blur. Recommended value >70
FORCEBG=0 #set this to 1 if you don't want to allow the user to configure blur. If set to 1, set all relevant values in profiles!
AUTOCAMNAME="Let the system decide..." #This is the text to show for automatic selection

REBOOTREQUIRED=0

VWCSTATE=$(get multimedia.webcam.virtual_background.enabled)

if [ $? -ne 0 ]; then
    zenity --error --width=400 --text "The firmware of your terminal does not yet support this feature. Please contact the helpdesk to get an update."
    exit;
else
    if [ "$VWCSTATE" = "false" ]; then
      if ! zenity --question --width=400 --title="Enable feature?" --text "The webcam controls are only available when enabling the VirtualCam feature.\n\nDo you want to do this now?"; then
        exit
      else
        setparam multimedia.webcam.virtual_background.enabled true
        VWCSTATE="true"
		REBOOTREQUIRED=1
      fi
    else
      if zenity --question --width=400 --title="What do you want to do?" --ok-label="Disable VirtualCam" --cancel-label="Change Settings" --text "Do you want to disable the feature completely or only change some settings?"; then
        setparam multimedia.webcam.virtual_background.enabled false
        VWCSTATE="false"
		REBOOTREQUIRED=1
      fi
    fi
    
    if [ "$VWCSTATE" = "true" ]; then
        #At this point we made sure that the virtual camera FEATURE is (to be) enabled.

        mapfile -t WCLIST < <(v4l2-ctl --list-devices | grep -v VirtualCam | grep ' (' | awk -F ' \\\(' '{print $1}' 2>/dev/null)

        DEFWC=$(zenity --list --width=300 \
          --title "Choose WebCam" \
          --text "Which webcam do you want to use as source?\n\nWarning for mobile devices:\nIf you happen to select an external camera,\nthe VirtualCam will fail if it is being disconnected." \
          --column="Camera" "${AUTOCAMNAME}" "${WCLIST[@]}")
        
        if [ $? -eq 0 ]; then
        
          if [ "$DEFWC" = "$AUTOCAMNAME" ]; then
            setparam multimedia.webcam.virtual_background.choose_webcam_by "first"
            setparam multimedia.webcam.virtual_background.webcam_name ""
          else
            setparam multimedia.webcam.virtual_background.choose_webcam_by "name"
            setparam multimedia.webcam.virtual_background.webcam_name "$DEFWC"
          fi
          
          # Set up blur if not forced
          if [ $FORCEBG -eq 0 ]; then
            if zenity --question --width=400 --ok-label="Ja" --cancel-label="Nein" --text "Do you want to blur your background?"; then
              setparam multimedia.webcam.virtual_background.blur $WCBLUR
            else
              setparam multimedia.webcam.virtual_background.blur 0
            fi
          fi
        else
          zenity --error --width=400 --title "Camera error" --text "You did not select a webcam.\nIf your system does not have a webcam connected, you can't use this feature."
          exit
        fi
    fi
    
    (
    echo "# Saving configuration locally."
    echo "25"
    sleep 0.5
    echo "50"
    echo "# Transmitting changes to UMS..."
    write_rmsettings
    echo "75"
	echo "# Applying configuration..."
	killwait_postsetupd
	echo "85"
	sleep 1
	echo "95"
    sleep 1
    echo "100"
    echo "# Ready"
    ) | zenity --progress --width=400 --text "Please be patient..." --percentage=0 --auto-close

	if [ $REBOOTREQUIRED -eq 1 ]; then
	  if zenity --question --width=400 --title="Reboot required" --ok-label="Reboot now" --cancel-label="Reboot later" --text "A reboot is required to apply the changes you made.\n\nDo you want to reboot now?"; then
        reboot
	  else
	    zenity --info --width=400 --text "configuration done.\n\nIf you happen to encounter issues (e.g. black screen) wile using VirtualCam, please reboot the terminal to apply all changes."
      fi
	fi

fi
